
class SecureToken:
    def __init__(self):
        self.email = None
        self.access_token = None
        self.refresh_token = None
        self.access_token_expires_at = None
        self.refresh_token_expires_at = None

