# events emitted by RATS
EVENT_COOK_ADDED = "cook_added"
EVENT_RESTAURANT_ADDED = "restaurant_added"
EVENT_MENU_UPLOADED = "menu_uploaded"

# events emitted by OCRA
EVENT_ORDER_CONFIRMED = "order_confirmed"
EVENT_RESTAURANT_RATED = "restaurant_rated"
EVENT_DRIVER_RATED = "driver_rated"

# events emitted by OPROC
EVENT_ORDER_READY_FOR_PICKUP = "order_ready_for_pickup"
EVENT_ORDER_IN_PROGRESS = "order_in_progress"
